Dual

Struct Dual 

pub struct Dual {
    pub v: f64,
    pub dv: f64,
}
A dual number (v, dv) representing a value and its first derivative.

All arithmetic operators and elementary functions implement the standard chain-rule so that derivatives propagate automatically.

Fields

v: f64

Primal (real) value.

dv: f64

Derivative (dual) component.

Implementations

Source

impl Dual

pub fn constant(c: f64) -> Self

Create a dual number representing the constant c (derivative = 0).

pub fn variable(x: f64) -> Self

Create a dual number representing the variable x with seed dx = 1.

pub fn sin(self) -> Self

Sine with chain rule: sin(u)' = cos(u) * u'.

pub fn cos(self) -> Self

Cosine with chain rule: cos(u)' = -sin(u) * u'.

pub fn exp(self) -> Self

Natural exponential with chain rule: exp(u)' = exp(u) * u'.

pub fn ln(self) -> Self

Natural logarithm with chain rule: ln(u)' = u'/u.

pub fn sqrt(self) -> Self

Square root with chain rule: sqrt(u)' = u' / (2 * sqrt(u)).

pub fn abs(self) -> Self

Absolute value with (sub)derivative: |u|' = sign(u) * u'.

pub fn powi(self, n: i32) -> Self

Integer power with chain rule: u^n' = n * u^(n-1) * u'.

pub fn powf(self, p: f64) -> Self

Floating-point power: u^p' = p * u^(p-1) * u'.

pub fn tan(self) -> Self

Tangent: tan(u)' = u' / cos²(u).

pub fn sinh(self) -> Self

Hyperbolic sine: sinh(u)' = cosh(u) * u'.

pub fn cosh(self) -> Self

Hyperbolic cosine: cosh(u)' = sinh(u) * u'.