pub fn kernel_eval(
kt: KernelType,
params: &KernelParams,
a: &[f64],
b: &[f64],
) -> f64Expand description
Evaluate the kernel between two input vectors a and b.
Returns the scalar covariance k(a, b).
pub fn kernel_eval(
kt: KernelType,
params: &KernelParams,
a: &[f64],
b: &[f64],
) -> f64Evaluate the kernel between two input vectors a and b.
Returns the scalar covariance k(a, b).