pub struct GaussianProcess {
pub kernel: KernelType,
pub params: KernelParams,
/* private fields */
}Expand description
A Gaussian process regressor using a stationary kernel.
Training points are stored internally. After GaussianProcess::fit the
GP can predict the posterior mean and variance at arbitrary test points.
Fields
kernel: KernelTypeKernel type.
params: KernelParamsKernel hyper-parameters.
Implementations
Sourceimpl GaussianProcess
impl GaussianProcess
Sourcepub fn new(kernel: KernelType, params: KernelParams) -> Self
pub fn new(kernel: KernelType, params: KernelParams) -> Self
Construct a new, unfitted GP with the given kernel and parameters.
Sourcepub fn fit(&mut self, x: Vec<Vec<f64>>, y: Vec<f64>) -> Result<(), String>
pub fn fit(&mut self, x: Vec<Vec<f64>>, y: Vec<f64>) -> Result<(), String>
Fit the GP to the given training data.
Panics
Panics if x and y have different lengths, or if x is empty.