pub struct AlignedVec<T> { /* private fields */ }Expand description
Cache-line-aligned vector wrapper.
On most modern x86-64 and ARM processors the cache line is 64 bytes. Aligning the start of a data buffer to a 64-byte boundary avoids false sharing between cores and helps the prefetcher.
Internally this uses a standard VecT` whose pointer is guaranteed to be
at least 64-byte aligned via a manual allocation strategy when the default
allocator does not already satisfy the requirement. On the vast majority of
platforms with jemalloc or mimalloc, 64-byte alignment for large arrays is
already the default, so this mainly serves as a documented guarantee.
Implementations
Sourceimpl<T: Default + Clone> AlignedVec<T>
impl<T: Default + Clone> AlignedVec<T>
Sourceimpl<T: Clone> AlignedVec<T>
impl<T: Clone> AlignedVec<T>