ConvexShape

Trait ConvexShape 

pub trait ConvexShape {
    // Required method
    fn support(&self, dir: [Real; 3]) -> [Real; 3];
}
Trait for convex shapes defined by a support function.

Required Methods

fn support(&self, dir: [Real; 3]) -> [Real; 3]

Return the support point of the shape in direction dir.

Implementors