detect_fold_point

Function detect_fold_point 

pub fn detect_fold_point(
    state_a: &ContinuationState,
    state_b: &ContinuationState,
    jac: &dyn Fn(&[f64], f64) -> Vec<Vec<f64>>,
) -> bool
Detect a fold (limit) point by checking for a sign change in the determinant of the Jacobian along two consecutive states.

Returns true if the determinants at state_a and state_b have opposite signs (or one of them is zero), indicating a fold between them.