pub fn root_locus_breakpoints(tf: &TransferFunction) -> Vec<f64>Expand description
Find the break-away/break-in points on the real axis for root locus.
These are points where dK/ds = 0 on the real axis.
pub fn root_locus_breakpoints(tf: &TransferFunction) -> Vec<f64>Find the break-away/break-in points on the real axis for root locus.
These are points where dK/ds = 0 on the real axis.