pub struct ProximalOperator {
pub lambda: f64,
}Expand description
A proximal operator parameterised by a regularisation strength lambda.
Fields
lambda: f64Regularisation strength λ > 0.
Implementations
Sourceimpl ProximalOperator
impl ProximalOperator
Sourcepub fn prox_l1(&self, x: f64) -> f64
pub fn prox_l1(&self, x: f64) -> f64
Apply the L1 (soft-thresholding) proximal operator: prox_{λ|·|}(x).
Sourcepub fn prox_l2_sq(&self, x: f64) -> f64
pub fn prox_l2_sq(&self, x: f64) -> f64
Apply the L2-squared proximal operator: prox_{λ||·||²/2}(x).
Sourcepub fn prox_huber_val(&self, x: f64, delta: f64) -> f64
pub fn prox_huber_val(&self, x: f64, delta: f64) -> f64
Apply the Huber proximal operator with delta parameter.
Sourcepub fn prox_box_indicator(&self, x: f64, lo: f64, hi: f64) -> f64
pub fn prox_box_indicator(&self, x: f64, lo: f64, hi: f64) -> f64
Apply the indicator proximal operator for the box [lo, hi].
The proximal map of the indicator function of a convex set is just the projection onto that set.
Sourcepub fn prox_l1_vec(&self, x: &[f64]) -> Vec<f64>
pub fn prox_l1_vec(&self, x: &[f64]) -> Vec<f64>
Apply the L1 proximal operator elementwise to a vector.
Sourcepub fn prox_l2_sq_vec(&self, x: &[f64]) -> Vec<f64>
pub fn prox_l2_sq_vec(&self, x: &[f64]) -> Vec<f64>
Apply the L2-squared proximal operator elementwise to a vector.