pub struct RecurrenceAnalysis {
pub recurrence_rate: f64,
pub determinism: f64,
pub mean_diagonal_length: f64,
pub max_diagonal_length: usize,
pub diagonal_entropy: f64,
pub laminarity: f64,
pub trapping_time: f64,
}Expand description
Recurrence quantification analysis (RQA) results.
Summarises the statistical structure of a recurrence plot via standard RQA measures.
Fields
recurrence_rate: f64Recurrence rate (RR): fraction of recurrent points.
determinism: f64Determinism (DET): fraction of recurrent points on diagonal lines ≥ min_line.
mean_diagonal_length: f64Mean diagonal line length (L_mean).
max_diagonal_length: usizeLongest diagonal line length (L_max).
diagonal_entropy: f64Entropy of diagonal line-length distribution (Shannon).
laminarity: f64Laminarity (LAM): fraction of recurrent points on vertical lines ≥ min_line.
trapping_time: f64Trapping time (TT): mean vertical line length.
Implementations
Sourceimpl RecurrenceAnalysis
impl RecurrenceAnalysis
Sourcepub fn compute(rp: &RecurrencePlot, min_line: usize) -> Self
pub fn compute(rp: &RecurrencePlot, min_line: usize) -> Self
Compute full RQA from a recurrence plot with minimum line length min_line.
min_line is the minimum length (≥ 1) for a line to be counted.