pub struct FunctionSpace {
pub basis: Vec<fn(f64) -> f64>,
}Expand description
A finite-dimensional function space spanned by a list of basis functions.
Each basis element is a plain function pointer fn(f64) -> f64 to avoid
lifetime complications with closures.
Fields
basis: Vec<fn(f64) -> f64>Basis functions spanning this space.
Implementations