pub struct BarycentricCoords {
pub u: f64,
pub v: f64,
pub w: f64,
}Expand description
Barycentric coordinate utilities.
Fields
u: f64First barycentric coordinate.
v: f64Second barycentric coordinate.
w: f64Third barycentric coordinate.
Implementations
Sourceimpl BarycentricCoords
impl BarycentricCoords
Sourcepub fn compute(v0: [f64; 3], v1: [f64; 3], v2: [f64; 3], p: [f64; 3]) -> Self
pub fn compute(v0: [f64; 3], v1: [f64; 3], v2: [f64; 3], p: [f64; 3]) -> Self
Compute barycentric coordinates of point p in triangle (v0,v1,v2).
Sourcepub fn is_inside(&self) -> bool
pub fn is_inside(&self) -> bool
Check if the barycentric coordinates represent a point inside the triangle.