betweenness_centrality

Function betweenness_centrality 

pub fn betweenness_centrality(graph: &Graph) -> Vec<f64>
Computes approximate betweenness centrality using Dijkstra for each source.

For each pair (s, t), counts how many shortest paths pass through each intermediate node and normalises by (n-1)*(n-2)/2. This is the unnormalised vertex betweenness centrality.