vec3_refract

Function vec3_refract 

pub fn vec3_refract(v: &Vec3, n: &Vec3, eta: Real) -> Option<Vec3>
Refract v about the unit normal n with relative index of refraction eta.

v must be normalized, n must be a unit normal pointing away from the surface on the same side as v. Returns None on total internal reflection.