pub struct EditDistance;Expand description
Edit (Levenshtein) distance metric on sequences.
The edit distance counts the minimum number of single-element insertions, deletions, and substitutions required to transform one sequence into another.
Implementations
Sourceimpl EditDistance
impl EditDistance
Sourcepub fn lcs_length(a: &[char], b: &[char]) -> usize
pub fn lcs_length(a: &[char], b: &[char]) -> usize
Compute the longest common subsequence length of two sequences.