check_scale_separation

Function check_scale_separation 

pub fn check_scale_separation(
    micro_length: f64,
    macro_length: f64,
    factor: f64,
) -> bool
Check scale separation: verifies that the micro length scale is at least factor times smaller than the macro length scale.