pub struct BDF2 {
pub max_iter: usize,
pub tol: f64,
}Expand description
Second-order Backward Differentiation Formula (BDF2) for stiff ODEs.
Uses the formula (3/2) y_{n+1} - 2 y_n + (1/2) y_{n-1} = h * f(t_{n+1}, y_{n+1}).
The first step is taken with implicit Euler to obtain y_1.
Fields
max_iter: usizeMaximum iterations per step.
tol: f64Convergence tolerance for fixed-point iteration.
Implementations
Sourceimpl BDF2
impl BDF2
Sourcepub fn default_params() -> Self
pub fn default_params() -> Self
Construct with default parameters.
Sourcepub fn step<F>(
&self,
s_curr: &OdeState,
s_prev: &OdeState,
h: f64,
f: &F,
) -> OdeState
pub fn step<F>( &self, s_curr: &OdeState, s_prev: &OdeState, h: f64, f: &F, ) -> OdeState
Perform one BDF2 step given y_n (s_curr) and y_{n-1} (s_prev).
Step size h must be the same as the previous step (constant step BDF2).
Uses Newton iteration with a diagonal finite-difference Jacobian for
robust handling of stiff problems.