pub struct CoverabilityTree {
pub nodes: Vec<CoverabilityNode>,
}Expand description
Coverability tree for a Petri net.
Can determine whether the net is bounded (no OMEGA entries exist).
Fields
nodes: Vec<CoverabilityNode>All nodes in the tree.
Implementations
Sourceimpl CoverabilityTree
impl CoverabilityTree
Sourcepub fn build(net: &PetriNet) -> Self
pub fn build(net: &PetriNet) -> Self
Build the coverability tree for net starting from its current marking.
Sourcepub fn is_bounded(&self) -> bool
pub fn is_bounded(&self) -> bool
Returns true if the net is bounded (no OMEGA tokens in the tree).
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Returns the total number of nodes in the tree.