pub struct StochasticPetriNet {
pub net: PetriNet,
pub rates: Vec<f64>,
}Expand description
A stochastic Petri net where each transition fires with a rate drawn from an exponential distribution.
Fields
net: PetriNetUnderlying classical Petri net.
rates: Vec<f64>Firing rates for each transition (exponential distribution parameter λ).
Implementations
Sourceimpl StochasticPetriNet
impl StochasticPetriNet
Sourcepub fn new(net: PetriNet, rates: Vec<f64>) -> Self
pub fn new(net: PetriNet, rates: Vec<f64>) -> Self
Create a stochastic Petri net from an existing PetriNet and a rate
vector (one rate per transition, in order).