StochasticDifferentialEquation

Struct StochasticDifferentialEquation 

pub struct StochasticDifferentialEquation;
SDE solver for dX = mu(X,t)dt + sigma(X,t)dW.

Implementations

Source

impl StochasticDifferentialEquation

pub fn euler_maruyama<F, G>( mu: F, sigma: G, x0: f64, t0: f64, t_end: f64, n_steps: usize, seed: u64, ) -> (Vec<f64>, Vec<f64>)
where F: Fn(f64, f64) -> f64, G: Fn(f64, f64) -> f64,

Euler-Maruyama scheme: X_{n+1} = X_n + mu(X_n, t_n)*dt + sigma(X_n, t_n)*sqrt(dt)*Z.

Strong order 0.5, weak order 1.0.

pub fn milstein<F, G, H>( mu: F, sigma: G, sigma_prime: H, x0: f64, t0: f64, t_end: f64, n_steps: usize, seed: u64, ) -> (Vec<f64>, Vec<f64>)
where F: Fn(f64, f64) -> f64, G: Fn(f64, f64) -> f64, H: Fn(f64, f64) -> f64,

Milstein scheme: adds a correction term for higher strong order (1.0).

X_{n+1} = X_n + mudt + sigmadW + 0.5sigmasigma’*(dW^2 - dt). sigma_prime is the derivative of sigma with respect to x.

pub fn runge_kutta_maruyama<F, G>( mu: F, sigma: G, x0: f64, t0: f64, t_end: f64, n_steps: usize, seed: u64, ) -> (Vec<f64>, Vec<f64>)
where F: Fn(f64, f64) -> f64, G: Fn(f64, f64) -> f64,

Runge-Kutta (Runge-Kutta-Maruyama) order 1 scheme for Ito SDEs.

Uses a predictor step to estimate the diffusion coefficient more accurately.

pub fn monte_carlo_paths<F, G>( mu: F, sigma: G, x0: f64, t0: f64, t_end: f64, n_steps: usize, n_paths: usize, seed: u64, ) -> Vec<Vec<f64>>
where F: Fn(f64, f64) -> f64 + Clone, G: Fn(f64, f64) -> f64 + Clone,

Simulate multiple paths (Monte Carlo ensemble).

Returns a matrix of shape (n_paths, n_steps+1).

pub fn strong_error_estimate<F, G>( mu: F, sigma: G, x0: f64, t0: f64, t_end: f64, seed: u64, n_steps_coarse: usize, n_steps_fine: usize, ) -> f64
where F: Fn(f64, f64) -> f64 + Clone, G: Fn(f64, f64) -> f64 + Clone,

Compute the strong order of convergence from a reference solution.

Returns the estimated strong error at the terminal time.

pub fn weak_order_estimate<F, G, H>( mu: F, sigma: G, functional: H, x0: f64, t0: f64, t_end: f64, n_steps: usize, n_paths: usize, seed: u64, ) -> f64
where F: Fn(f64, f64) -> f64 + Clone, G: Fn(f64, f64) -> f64 + Clone, H: Fn(f64) -> f64,

Compute the weak order of convergence via expected value of a functional.

Returns E[f(X(T))] estimated from n_paths Monte Carlo paths.

pub fn stratonovich_to_ito<G, H>( strat_mu: f64, sigma_val: f64, sigma_prime: f64, _sigma: G, _sigma_p: H, ) -> f64
where G: Fn(f64, f64) -> f64, H: Fn(f64, f64) -> f64,

Stratonovich to Ito conversion: add the correction term -0.5sigmasigma’.

Returns the Ito drift given the Stratonovich drift and diffusion.