pub struct RgFlow {
pub beta: BetaFunction,
pub gamma0: f64,
pub eta0: f64,
}Expand description
Callan-Symanzik RG flow for coupling and mass.
Implements μ dg/dμ = β(g), μ dm/dμ = −γ_m(g) m, where γ_m is the mass anomalous dimension.
Fields
beta: BetaFunctionBeta function governing the coupling flow.
gamma0: f64One-loop mass anomalous dimension coefficient γ₀ (γ_m = γ₀ g²).
eta0: f64Field anomalous dimension coefficient η₀ (η = η₀ g²).
Implementations
Sourceimpl RgFlow
impl RgFlow
Sourcepub fn new(beta: BetaFunction, gamma0: f64, eta0: f64) -> Self
pub fn new(beta: BetaFunction, gamma0: f64, eta0: f64) -> Self
Construct a new RG flow with given beta function and anomalous dimension coefficients.
Sourcepub fn gamma_mass(&self, g: f64) -> f64
pub fn gamma_mass(&self, g: f64) -> f64
Anomalous dimension of the mass at coupling g: γ_m(g) = γ₀ g².
Sourcepub fn integrate(&self, g0: f64, m0: f64, t_max: f64, n: usize) -> RgFlowResult
pub fn integrate(&self, g0: f64, m0: f64, t_max: f64, n: usize) -> RgFlowResult
Integrate the full RG flow from t=0 to t=t_max with n steps.
Returns a RgFlowResult containing the full trajectory.
Sourcepub fn nu_exponent(&self) -> Option<f64>
pub fn nu_exponent(&self) -> Option<f64>
Correlation length exponent ν from the eigenvalue of the linearized beta function at the fixed point: ν = −1/ω.