Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

brute_force_batch_knn
Compute the k-nearest neighbors of each point in queries from points.
brute_force_knn
Compute the k-nearest neighbors of query from points using brute force.
kd_batch_knn
Batch k-nearest-neighbor query.
kd_cross_match
Find all pairs of points within distance r between two KD-trees.
kdtree_stats
Compute statistics for a KdTree.
morton_decode
Decode a Morton code back to (x, y, z) integer coordinates.
morton_encode
Compute the Morton code (Z-order curve index) for a 3D integer coordinate.
octree_stats
Compute statistics for an Octree.
regular_grid_3d
Build a uniform-spacing grid of points in 3D.
spatial_join
Spatial join: find all pairs (i, j) from two point sets within distance r.
spatial_self_join
Spatial self-join: find all pairs (i, j) with i < j within distance r.