pub struct ErrorCollector {
pub errors: Vec<PhysicsError>,
pub max_errors: usize,
}Expand description
Collect multiple errors during a batch operation.
Fields
errors: Vec<PhysicsError>Collected errors.
max_errors: usizeMaximum number of errors to collect before stopping.
Implementations
Sourceimpl ErrorCollector
impl ErrorCollector
Sourcepub fn with_limit(max: usize) -> Self
pub fn with_limit(max: usize) -> Self
Create a collector with a specific max error limit.
Sourcepub fn push(&mut self, error: PhysicsError) -> bool
pub fn push(&mut self, error: PhysicsError) -> bool
Add an error. Returns true if the error limit has been reached.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true if any errors were collected.
Sourcepub fn drain(&mut self) -> Vec<PhysicsError>
pub fn drain(&mut self) -> Vec<PhysicsError>
Drain all errors, returning them.
Sourcepub fn into_result(self) -> PhysicsResult<()>
pub fn into_result(self) -> PhysicsResult<()>
Convert into a result: Ok if no errors, Err with first error otherwise.