Midpoint

Struct Midpoint 

pub struct Midpoint;
Explicit midpoint (Runge-Kutta 2) integrator.

k1_v = a_n,  k1_q = v_n
k2_v = a_n,  k2_q = v_n + k1_v * dt/2
v_{n+1} = v_n + k2_v * dt
q_{n+1} = q_n + k2_q * dt

For constant forces this gives the same result as the explicit Euler update for velocity but uses the midpoint velocity for position.