pub struct MapperNode {
pub point_indices: Vec<usize>,
pub cover_index: usize,
}Expand description
A node in a Mapper graph.
Each node corresponds to a cluster of points from one cover set.
Fields
point_indices: Vec<usize>Indices of points in the original point cloud assigned to this node.
cover_index: usizeCover interval index that generated this node.