pub trait PhysicsInterpolatable: Sized {
// Required method
fn lerp_state(&self, other: &Self, t: Real) -> Self;
}Expand description
Trait for physics state objects that support linear interpolation.
Required Methods
Sourcefn lerp_state(&self, other: &Self, t: Real) -> Self
fn lerp_state(&self, other: &Self, t: Real) -> Self
Linearly interpolate between self and other at blend factor t ∈ [0,1].
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.