Sleepable

Trait Sleepable 

pub trait Sleepable {
    // Required methods
    fn is_sleeping(&self) -> bool;
    fn wake(&mut self);
    fn sleep(&mut self);

    // Provided method
    fn should_sleep(
        &self,
        speed_sq: Real,
        threshold_sq: Real,
        accumulated_sleep_time: Real,
        time_to_sleep: Real,
    ) -> bool { ... }
}
Trait for bodies that can sleep when below activity thresholds.

Required Methods

fn is_sleeping(&self) -> bool

Whether the body is currently sleeping.

fn wake(&mut self)

Wake the body from sleep.

fn sleep(&mut self)

Put the body to sleep, zeroing velocities.

Provided Methods

fn should_sleep( &self, speed_sq: Real, threshold_sq: Real, accumulated_sleep_time: Real, time_to_sleep: Real, ) -> bool

Test whether the body should fall asleep given its speed squared and the world’s thresholds.

Implementors