Module unit_conversion

Module unit_conversion 

Unit conversion and fundamental physical constants.

Provides enumerations for common measurement units and conversion functions between them, as well as a struct containing widely-used physical constants in SI units.

Structs

PhysicalConstants
Fundamental physical constants in SI units (CODATA 2018 values).

Enums

EnergyUnit
Units of energy.
LengthUnit
Units of length.
MassUnit
Units of mass.
PressureUnit
Units of pressure.
TemperatureUnit
Units of temperature.

Functions

convert_energy
Convert an energy value from from units to to units.
convert_length
Convert a length value from from units to to units.
convert_mass
Convert a mass value from from units to to units.
convert_pressure
Convert a pressure value from from units to to units.
convert_temperature
Convert a temperature value from from units to to units.