pub struct Island {
pub body_indices: Vec<usize>,
pub all_sleeping: bool,
}Expand description
An island is a group of dynamically connected bodies that can be solved independently from the rest of the world.
Fields
body_indices: Vec<usize>Indices into the body storage that belong to this island.
all_sleeping: boolWhether all bodies in this island are sleeping.
Implementations