pub struct TaylorExpand {
pub center: f64,
pub f0: f64,
pub f1: f64,
pub f2: f64,
pub f3: f64,
}Expand description
Stores the value of a function and its first three derivatives at a point, enabling Taylor polynomial evaluation.
Fields
center: f64The expansion center x₀.
f0: f64f(x₀).
f1: f64f'(x₀).
f2: f64f''(x₀) (second derivative).
f3: f64f'''(x₀) (third derivative).
Implementations
Sourceimpl TaylorExpand
impl TaylorExpand
Sourcepub fn build<F>(f: F, x0: f64) -> Self
pub fn build<F>(f: F, x0: f64) -> Self
Build a TaylorExpand by numerically estimating derivatives via
forward-mode AD and central finite differences.
f1— exact via autodiff.f2— via central difference off'.f3— via central difference off''.