pub enum Prior {
Uniform {
low: f64,
high: f64,
},
Gaussian {
mean: f64,
std: f64,
},
Laplace {
mu: f64,
b: f64,
},
Jeffreys,
Dirichlet {
alpha: Vec<f64>,
},
Beta {
alpha: f64,
beta: f64,
},
Gamma {
shape: f64,
rate: f64,
},
}Expand description
Supported prior distribution families.
Variants
Uniform
Uniform prior on [low, high].
Gaussian
Gaussian (normal) prior N(mean, std²).
Laplace
Laplace (double-exponential) prior with location μ and scale b.
Jeffreys
Jeffreys (improper) scale prior ∝ 1/θ for θ > 0.
Dirichlet
Dirichlet prior over a simplex with concentration parameters α.
Beta
Beta prior Beta(alpha, beta) on [0, 1].
Gamma
Gamma prior Gamma(shape, rate) on (0, ∞).
Implementations
Sourceimpl Prior
impl Prior
Sourcepub fn log_density(&self, theta: f64) -> f64
pub fn log_density(&self, theta: f64) -> f64
Returns the log prior density log p(θ) for a scalar parameter θ.
Returns f64::NEG_INFINITY when θ is outside the support.
Sourcepub fn dirichlet_log_density(&self, x: &[f64]) -> f64
pub fn dirichlet_log_density(&self, x: &[f64]) -> f64
Returns the log density of a Dirichlet prior for a probability vector x.
Returns f64::NEG_INFINITY when the dimensions do not match.