pub struct BayesianLinearRegression {
pub alpha_prior: f64,
pub beta_noise: f64,
pub posterior_mean: Vec<f64>,
pub posterior_cov: Vec<Vec<f64>>,
}Expand description
Bayesian linear regression with conjugate Gaussian prior on weights.
Model: y = X w + ε, ε ~ N(0, σ² I). Prior: w ~ N(w₀, α⁻¹ I).
Fields
alpha_prior: f64Prior precision α (= 1/σ_prior²).
beta_noise: f64Noise precision β (= 1/σ_noise²).
posterior_mean: Vec<f64>Posterior mean weights (set after fitting).
posterior_cov: Vec<Vec<f64>>Posterior covariance matrix (row-major, set after fitting).
Implementations
Sourceimpl BayesianLinearRegression
impl BayesianLinearRegression
Sourcepub fn new(alpha_prior: f64, beta_noise: f64) -> Self
pub fn new(alpha_prior: f64, beta_noise: f64) -> Self
Creates a new Bayesian linear regression model.
Arguments
alpha_prior- Prior precision (inverse variance) on weights.beta_noise- Noise precision.
Sourcepub fn fit(&mut self, x_mat: &[Vec<f64>], y: &[f64])
pub fn fit(&mut self, x_mat: &[Vec<f64>], y: &[f64])
Fits the model to design matrix x_mat (n × d) and targets y (n).
Computes the posterior mean and covariance analytically.
Sourcepub fn predict_mean(&self, x_new: &[f64]) -> f64
pub fn predict_mean(&self, x_new: &[f64]) -> f64
Returns the predictive mean for a new input vector x_new.
Sourcepub fn predict_variance(&self, x_new: &[f64]) -> f64
pub fn predict_variance(&self, x_new: &[f64]) -> f64
Returns the predictive variance for a new input x_new.
σ²_pred = 1/β + x^T S_N x.