pub struct FrontdoorCriterion {
pub graph: CausalGraph,
}Expand description
Implements the frontdoor adjustment formula for causal effect identification.
The frontdoor criterion allows identification of causal effects through a
mediator set M when direct adjustment is not possible.
Fields
graph: CausalGraphThe causal graph.
Implementations
Sourceimpl FrontdoorCriterion
impl FrontdoorCriterion
Sourcepub fn new(graph: CausalGraph) -> Self
pub fn new(graph: CausalGraph) -> Self
Create a new frontdoor criterion object.
Sourcepub fn check(
&self,
treatment: usize,
outcome: usize,
mediator_set: &[usize],
) -> bool
pub fn check( &self, treatment: usize, outcome: usize, mediator_set: &[usize], ) -> bool
Check if mediator_set satisfies the frontdoor criterion for identifying
the effect of treatment on outcome.
Conditions:
- All directed paths from
treatmenttooutcomeare intercepted byM. - No backdoor path from
treatmenttoM(or blocked bytreatment). - All backdoor paths from
Mtooutcomeare blocked bytreatment.