pub struct KSvd {
pub n_atoms: usize,
pub sparsity: usize,
pub n_iter: usize,
}Expand description
K-SVD dictionary learning algorithm.
Alternates between a sparse coding stage (OMP) and a dictionary update stage (rank-1 SVD update) to learn an overcomplete dictionary adapted to training data.
Reference: Aharon, Elad & Bruckstein (2006).
Fields
n_atoms: usizeNumber of dictionary atoms (columns).
sparsity: usizeTarget sparsity per signal.
n_iter: usizeNumber of training iterations.
Implementations
Sourceimpl KSvd
impl KSvd
Sourcepub fn new(n_atoms: usize, sparsity: usize, n_iter: usize) -> Self
pub fn new(n_atoms: usize, sparsity: usize, n_iter: usize) -> Self
Create a new K-SVD learner.
n_atoms— number of dictionary atomssparsity— maximum number of atoms per signaln_iter— number of alternating optimisation iterations
Sourcepub fn fit(&self, signals: &[Vec<f64>]) -> Vec<Vec<f64>>
pub fn fit(&self, signals: &[Vec<f64>]) -> Vec<Vec<f64>>
Learn a dictionary from training signals.
signals— list of training signals (each of the same lengthd)
Returns a dictionary matrix D of shape d × n_atoms (columns are atoms,
stored as Vec<Vecf64> in row-major form, i.e. D[i][j] is row i, atom j).