Control theory: PID, state-space, LQR, Kalman filter, EKF, Bode analysis, root locus, Ziegler-Nichols auto-tuning, lead/lag compensator, poles/zeros.
Overview
This module provides classical and modern control theory building blocks:
PidController— PID with anti-windup, derivative filter, output clampingStateSpaceModel— A, B, C, D matrices; step response; stability checkLqrController— LQR via discrete algebraic Riccati equation (iterative)KalmanFilter— discrete Kalman filter: predict + updateExtendedKalmanFilter— EKF with Jacobian-based linearizationBodeAnalysis— gain/phase at frequencies; gain/phase marginsRootLocus— closed-loop poles vs gain K; breakaway pointsZieglerNichols— auto-tune PID from ultimate gain/periodLeadLagCompensator— lead/lag compensator transfer functionPolesZeros— transfer function poles, zeros, DC gain, step response
Structs
- Bode
Analysis - Bode analysis for a transfer function given numerator and denominator polynomials.
- Bode
Point - A single point on a Bode plot.
- Extended
Kalman Filter - Extended Kalman Filter (EKF) with Jacobian-based linearization.
- Kalman
Filter - Discrete Kalman filter.
- Lead
LagCompensator - Lead or lag compensator: C(s) = Kc * (s + z) / (s + p).
- LqrController
- Discrete Linear Quadratic Regulator (LQR) controller.
- PidController
- A PID controller with anti-windup, derivative filter, and output clamping.
- Poles
Zeros - Transfer function representation via poles, zeros, and DC gain.
- Root
Locus - Root locus computation: closed-loop poles as a function of gain K.
- Root
Locus Point - A point on the root locus.
- State
Space Model - Discrete-time linear state-space model: x[k+1] = Ax[k] + Bu[k], y[k] = Cx[k] + Du[k].
- Ziegler
Nichols - Ziegler-Nichols auto-tuning: compute PID gains from ultimate gain and period.
- ZnGains
- PID gains recommended by Ziegler-Nichols method.