pub fn reflect_direction(d: &Vec3, n: &Vec3) -> Vec3
Compute the reflection of direction d about unit normal n.
d
n
Equivalent to vec3_reflect_about_normal but uses the physics convention where d points toward the surface.
vec3_reflect_about_normal