ReduceOperator

Trait ReduceOperator 

pub trait ReduceOperator:
    Send
    + Sync
    + 'static {
    type Acc: Clone + Send + Sync + 'static;
    type Item: Clone + Send + Sync + 'static;
    type Result;

    // Required methods
    fn identity(&self) -> Self::Acc;
    fn fold(&self, acc: Self::Acc, item: Self::Item) -> Self::Acc;
    fn combine(&self, left: Self::Acc, right: Self::Acc) -> Self::Acc;
    fn finalize(&self, acc: Self::Acc) -> Self::Result;
}
Reduce with a custom operator struct for more complex reductions.

The operator must provide identity, combine, and finalize methods.

Required Associated Types

type Acc: Clone + Send + Sync + 'static

The accumulator type.

type Item: Clone + Send + Sync + 'static

The input element type.

type Result

The final result type.

Required Methods

fn identity(&self) -> Self::Acc

Identity element for the accumulator.

fn fold(&self, acc: Self::Acc, item: Self::Item) -> Self::Acc

Fold a single item into the accumulator.

fn combine(&self, left: Self::Acc, right: Self::Acc) -> Self::Acc

Combine two accumulators.

fn finalize(&self, acc: Self::Acc) -> Self::Result

Convert the final accumulator to the result.

Implementors