pub fn correlation(x: &[f64], y: &[f64]) -> f64
Returns the Pearson correlation coefficient of x and y.
x
y
Returns 0.0 when either standard deviation is zero or there are fewer than 2 paired values.
0.0