pub struct PoissonProcess {
pub rate: f64,
/* private fields */
}Expand description
Homogeneous and inhomogeneous Poisson processes.
Fields
rate: f64Constant rate for homogeneous process.
Implementations
Sourceimpl PoissonProcess
impl PoissonProcess
Sourcepub fn new(rate: f64, seed: u64) -> Self
pub fn new(rate: f64, seed: u64) -> Self
Creates a homogeneous Poisson process with constant rate.
Sourcepub fn arrivals(&self, t_end: f64) -> Vec<f64>
pub fn arrivals(&self, t_end: f64) -> Vec<f64>
Generate arrival times for a homogeneous Poisson process on [0, t_end].
Inter-arrival times are Exp(rate) distributed.
Sourcepub fn inhomogeneous_arrivals<F>(
&self,
t_end: f64,
lambda_max: f64,
lambda_fn: F,
) -> Vec<f64>
pub fn inhomogeneous_arrivals<F>( &self, t_end: f64, lambda_max: f64, lambda_fn: F, ) -> Vec<f64>
Generate arrival times for an inhomogeneous Poisson process with intensity lambda(t)
using Lewis-Shedler thinning. lambda_max must bound lambda(t) from above.
Sourcepub fn inter_arrival_times(&self, n: usize) -> Vec<f64>
pub fn inter_arrival_times(&self, n: usize) -> Vec<f64>
Inter-arrival times for a homogeneous Poisson process (exactly n arrivals).