pub struct Sphere {
pub center: Vec3,
pub radius: Real,
}Expand description
A sphere in 3D space.
Fields
center: Vec3Center of the sphere.
radius: RealRadius of the sphere.
Implementations
Sourceimpl Sphere
impl Sphere
Sourcepub fn contains_point(&self, point: &Vec3) -> bool
pub fn contains_point(&self, point: &Vec3) -> bool
Test if point is inside or on the surface of the sphere.
Sourcepub fn overlaps_sphere(&self, other: &Sphere) -> bool
pub fn overlaps_sphere(&self, other: &Sphere) -> bool
Test if this sphere overlaps another sphere.
Sourcepub fn overlaps_aabb(&self, aabb: &Aabb) -> bool
pub fn overlaps_aabb(&self, aabb: &Aabb) -> bool
Test if this sphere overlaps an AABB.
Sourcepub fn ray_intersect(&self, ray: &Ray) -> Option<Real>
pub fn ray_intersect(&self, ray: &Ray) -> Option<Real>
Ray–sphere intersection. Returns the entry t-value or None.
Sourcepub fn surface_area(&self) -> Real
pub fn surface_area(&self) -> Real
Surface area of the sphere.
Sourcepub fn bounding_sphere(points: &[Vec3]) -> Option<Sphere>
pub fn bounding_sphere(points: &[Vec3]) -> Option<Sphere>
Minimum enclosing sphere of a set of points (Ritter’s algorithm).