pub struct TensorBasis;Expand description
Tensor basis transformation utilities.
Implementations
Sourceimpl TensorBasis
impl TensorBasis
Sourcepub fn rotation_z(theta: f64) -> Tensor2
pub fn rotation_z(theta: f64) -> Tensor2
Build the 3×3 rotation matrix for an angle theta (radians) about the Z axis.
Sourcepub fn rotation_x(theta: f64) -> Tensor2
pub fn rotation_x(theta: f64) -> Tensor2
Build the 3×3 rotation matrix for an angle theta about the X axis.
Sourcepub fn rotation_y(theta: f64) -> Tensor2
pub fn rotation_y(theta: f64) -> Tensor2
Build the 3×3 rotation matrix for an angle theta about the Y axis.