pub struct BodyArena { /* private fields */ }Expand description
A generational arena storing bodies.
Implementations
Sourceimpl BodyArena
impl BodyArena
Sourcepub fn insert(&mut self, body: Body) -> BodyHandle
pub fn insert(&mut self, body: Body) -> BodyHandle
Insert a body and return its handle.
Sourcepub fn remove(&mut self, handle: BodyHandle) -> Option<Body>
pub fn remove(&mut self, handle: BodyHandle) -> Option<Body>
Remove a body and free its slot.
Sourcepub fn get(&self, handle: BodyHandle) -> Option<&Body>
pub fn get(&self, handle: BodyHandle) -> Option<&Body>
Get an immutable reference to a body by handle.
Sourcepub fn get_mut(&mut self, handle: BodyHandle) -> Option<&mut Body>
pub fn get_mut(&mut self, handle: BodyHandle) -> Option<&mut Body>
Get a mutable reference to a body by handle.
Sourcepub fn live_indices(&self) -> impl Iterator<Item = usize> + '_
pub fn live_indices(&self) -> impl Iterator<Item = usize> + '_
Iterate over all live body indices.